@@ -101,6 +101,7 @@ export function ClassProperty(node: Object) {
 }
 
 export function ClassPrivateProperty(node: Object) {
+  this.printJoin(node.decorators, node);
   if (node.static) {
     this.word("static");
     this.space();
@@ -133,3 +134,18 @@ export function _classMethodHead(node) {
   this.tsPrintClassMemberModifiers(node, /* isField */ false);
   this._methodHead(node);
 }
+
+export function StaticBlock(node) {
+  this.word("static");
+  this.space();
+  this.token("{");
+  if (node.body.length === 0) {
+    this.token("}");
+  } else {
+    this.newline();
+    this.printSequence(node.body, node, {
+      indent: true,
+    });
+    this.rightBrace();
+  }
+}
