@@ -27,4 +27,23 @@ type T8 = {
 };
 type T9 = {
   [param: string]: U
-};
\ No newline at end of file
+};
+type T10 = {...};
+type T11 = {
+  a: {
+    b: {
+      c: {...},
+      ...
+    },
+    ...
+  }
+};
+type T12 = {
+  foo: number,
+  ...
+};
+type T13 = {
+  foo: number,
+  bar: string,
+  ...
+};
