@@ -1,6 +1,7 @@
-async function asdf() {
+async function foo() {
   (await 1) || (await 2);
   (await b)();
+  (await b)?.();
   new (await b)();
   true ? (await 1) : (await 2);
   await (1 ? 2 : 3);
@@ -10,4 +11,5 @@ async function asdf() {
 
 async function a(b) {
   (await xhr({ url: "views/test.html" })).data;
+  (await replay())?.data;
 }
