@@ -12,7 +12,7 @@ class A6 extends class {} {}
 
 class A7 extends (B ? C : D) {}
 
-class A8 extends (new B()) {}
+class A8 extends new B() {}
 
 class A9 extends (B, C) {}
 
@@ -32,4 +32,4 @@ async function f1() {
 
 function* f2() {
   class A16 extends (yield 1) {}
-}
\ No newline at end of file
+}
