@@ -1,6 +1,7 @@
-function* asdf() {
+function* foo() {
   (yield 1) || (yield 2);
   (yield b)();
+  (yield b)?.();
   new (yield b)();
   (yield 1) ? (yield 2) : (yield 3);
   yield (1 ? 2 : 3);
@@ -9,6 +10,7 @@ function* asdf() {
 
 function* a(b) {
   (yield xhr({ url: "views/test.html" })).data;
+  (yield replay())?.data;
 }
 
 (async function* () {
