@@ -8,7 +8,6 @@ import vm from "vm";
 import "core-js/stable";
 import "regenerator-runtime/runtime";
 import register from "@babel/register";
-import resolve from "resolve";
 
 import pkg from "../package.json";
 
@@ -209,8 +208,8 @@ if (program.eval || program.print) {
 // We have to handle require ourselves, as we want to require it in the context of babel-register
 function requireArgs() {
   if (program.require) {
-    require(resolve.sync(program.require, {
-      basedir: process.cwd(),
+    require(require.resolve(program.require, {
+      paths: [process.cwd()],
     }));
   }
 }
