@@ -1262,7 +1262,7 @@ export type TsTypePredicate = TsTypeBase & {
   type: "TSTypePredicate",
   parameterName: Identifier | TsThisType,
   typeAnnotation: TsTypeAnnotation,
-  asserts?: boolean,
+  asserts: boolean,
 };
 
 // `typeof` operator
