@@ -1,8 +1,6 @@
 function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
 
-let Foo =
-/*#__PURE__*/
-function () {
+let Foo = /*#__PURE__*/function () {
   "use strict";
 
   function Foo() {
