@@ -10,17 +10,18 @@ let Hello = function Hello() {
   };
 };
 
-let Outer =
-/*#__PURE__*/
-function (_Hello) {
+let Outer = /*#__PURE__*/function (_Hello) {
   babelHelpers.inherits(Outer, _Hello);
 
+  var _super = babelHelpers.createSuper(Outer);
+
   function Outer() {
+    let _this2;
+
     var _this;
 
     babelHelpers.classCallCheck(this, Outer);
-
-    var _this2 = _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(Outer).call(this));
+    _this2 = _this = _super.call(this);
 
     let Inner = function Inner() {
       babelHelpers.classCallCheck(this, Inner);
