@@ -1,6 +1,6 @@
-var Foo =
-/*#__PURE__*/
-function () {
+var _foo = babelHelpers.classPrivateFieldLooseKey("foo");
+
+var Foo = /*#__PURE__*/function () {
   "use strict";
 
   function Foo() {
@@ -22,5 +22,3 @@ function () {
   }]);
   return Foo;
 }();
-
-var _foo = babelHelpers.classPrivateFieldLooseKey("foo");
