@@ -1,15 +1,17 @@
-var Child =
-/*#__PURE__*/
-function (_Parent) {
+var _scopedFunctionWithThis = babelHelpers.classPrivateFieldLooseKey("scopedFunctionWithThis");
+
+var Child = /*#__PURE__*/function (_Parent) {
   "use strict";
 
   babelHelpers.inherits(Child, _Parent);
 
+  var _super = babelHelpers.createSuper(Child);
+
   function Child() {
     var _this;
 
     babelHelpers.classCallCheck(this, Child);
-    _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(Child).call(this));
+    _this = _super.call(this);
     Object.defineProperty(babelHelpers.assertThisInitialized(_this), _scopedFunctionWithThis, {
       writable: true,
       value: function value() {
@@ -21,5 +23,3 @@ function (_Parent) {
 
   return Child;
 }(Parent);
-
-var _scopedFunctionWithThis = babelHelpers.classPrivateFieldLooseKey("scopedFunctionWithThis");
