@@ -1,6 +1,6 @@
-var Foo =
-/*#__PURE__*/
-function () {
+var _foo = babelHelpers.classPrivateFieldLooseKey("foo");
+
+var Foo = /*#__PURE__*/function () {
   "use strict";
 
   function Foo() {
@@ -16,8 +16,6 @@ function () {
   return Foo;
 }();
 
-var _foo = babelHelpers.classPrivateFieldLooseKey("foo");
-
 Object.defineProperty(Foo, _foo, {
   writable: true,
   value: function (x) {
