@@ -1,15 +1,17 @@
-var Foo =
-/*#__PURE__*/
-function (_Bar) {
+var _bar = babelHelpers.classPrivateFieldLooseKey("bar");
+
+var Foo = /*#__PURE__*/function (_Bar) {
   "use strict";
 
   babelHelpers.inherits(Foo, _Bar);
 
+  var _super = babelHelpers.createSuper(Foo);
+
   function Foo() {
     var _this;
 
     babelHelpers.classCallCheck(this, Foo);
-    _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(Foo).call(this));
+    _this = _super.call(this);
     Object.defineProperty(babelHelpers.assertThisInitialized(_this), _bar, {
       writable: true,
       value: "foo"
@@ -19,5 +21,3 @@ function (_Bar) {
 
   return Foo;
 }(Bar);
-
-var _bar = babelHelpers.classPrivateFieldLooseKey("bar");
