@@ -1,6 +1,8 @@
-var Point =
-/*#__PURE__*/
-function () {
+var _x = new WeakMap();
+
+var _y = new WeakMap();
+
+var Point = /*#__PURE__*/function () {
   "use strict";
 
   function Point(x = 0, y = 0) {
@@ -49,7 +51,3 @@ function () {
   }]);
   return Point;
 }();
-
-var _x = new WeakMap();
-
-var _y = new WeakMap();
