@@ -1,15 +1,17 @@
-var Child =
-/*#__PURE__*/
-function (_Parent) {
+var _scopedFunctionWithThis = new WeakMap();
+
+var Child = /*#__PURE__*/function (_Parent) {
   "use strict";
 
   babelHelpers.inherits(Child, _Parent);
 
+  var _super = babelHelpers.createSuper(Child);
+
   function Child() {
     var _this;
 
     babelHelpers.classCallCheck(this, Child);
-    _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(Child).call(this));
+    _this = _super.call(this);
 
     _scopedFunctionWithThis.set(babelHelpers.assertThisInitialized(_this), {
       writable: true,
@@ -23,5 +25,3 @@ function (_Parent) {
 
   return Child;
 }(Parent);
-
-var _scopedFunctionWithThis = new WeakMap();
