@@ -1,3 +1,5 @@
+var _outer = new WeakMap();
+
 var Outer = function Outer() {
   "use strict";
 
@@ -8,18 +10,16 @@ var Outer = function Outer() {
     value: void 0
   });
 
-  var Test =
-  /*#__PURE__*/
-  function (_babelHelpers$classPr) {
+  var Test = /*#__PURE__*/function (_babelHelpers$classPr) {
     babelHelpers.inherits(Test, _babelHelpers$classPr);
 
+    var _super = babelHelpers.createSuper(Test);
+
     function Test() {
       babelHelpers.classCallCheck(this, Test);
-      return babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(Test).apply(this, arguments));
+      return _super.apply(this, arguments);
     }
 
     return Test;
   }(babelHelpers.classPrivateFieldGet(this, _outer));
 };
-
-var _outer = new WeakMap();
