@@ -1,6 +1,4 @@
-var A =
-/*#__PURE__*/
-function () {
+var A = /*#__PURE__*/function () {
   "use strict";
 
   function A() {
@@ -16,22 +14,24 @@ function () {
   return A;
 }();
 
-var B =
-/*#__PURE__*/
-function (_A) {
+var _foo = new WeakMap();
+
+var B = /*#__PURE__*/function (_A) {
   "use strict";
 
   babelHelpers.inherits(B, _A);
 
+  var _super = babelHelpers.createSuper(B);
+
   function B(...args) {
-    var _this;
+    var _thisSuper, _this;
 
     babelHelpers.classCallCheck(this, B);
-    _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(B).call(this, ...args));
+    _this = _super.call(this, ...args);
 
     _foo.set(babelHelpers.assertThisInitialized(_this), {
       writable: true,
-      value: babelHelpers.get(babelHelpers.getPrototypeOf(B.prototype), "foo", babelHelpers.assertThisInitialized(_this)).call(babelHelpers.assertThisInitialized(_this))
+      value: babelHelpers.get((_thisSuper = babelHelpers.assertThisInitialized(_this), babelHelpers.getPrototypeOf(B.prototype)), "foo", _thisSuper).call(_thisSuper)
     });
 
     return _this;
@@ -39,5 +39,3 @@ function (_A) {
 
   return B;
 }(A);
-
-var _foo = new WeakMap();
