@@ -1,15 +1,17 @@
-var Foo =
-/*#__PURE__*/
-function (_Bar) {
+var _bar = new WeakMap();
+
+var Foo = /*#__PURE__*/function (_Bar) {
   "use strict";
 
   babelHelpers.inherits(Foo, _Bar);
 
+  var _super = babelHelpers.createSuper(Foo);
+
   function Foo() {
     var _this;
 
     babelHelpers.classCallCheck(this, Foo);
-    _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(Foo).call(this));
+    _this = _super.call(this);
 
     _bar.set(babelHelpers.assertThisInitialized(_this), {
       writable: true,
@@ -21,5 +23,3 @@ function (_Bar) {
 
   return Foo;
 }(Bar);
-
-var _bar = new WeakMap();
