@@ -1,15 +1,15 @@
-var Foo =
-/*#__PURE__*/
-function (_Bar) {
+var Foo = /*#__PURE__*/function (_Bar) {
   "use strict";
 
   babelHelpers.inherits(Foo, _Bar);
 
+  var _super = babelHelpers.createSuper(Foo);
+
   function Foo() {
     var _this;
 
     babelHelpers.classCallCheck(this, Foo);
-    _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(Foo).call(this));
+    _this = _super.call(this);
     _this.bar = "foo";
     return _this;
   }
