@@ -1,10 +1,12 @@
+let _ref;
+
 function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
 
 function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
 
 function _classNameTDZError(name) { throw new Error("Class \"" + name + "\" cannot be referenced in computed property keys."); }
 
-var _ref = (_classNameTDZError("C"), C) + 3;
+_ref = (_classNameTDZError("C"), C) + 3;
 
 let C = function C() {
   "use strict";
