@@ -1,8 +1,8 @@
 async function g() {
-  let A = babelHelpers.decorate([dec], function (_initialize, _super) {
+  let A = babelHelpers.decorate([dec], function (_initialize, _await$B) {
     "use strict";
 
-    class A extends _super {
+    class A extends _await$B {
       constructor(...args) {
         super(...args);
 
@@ -15,5 +15,5 @@ async function g() {
       F: A,
       d: []
     };
-  }, (await B));
+  }, await B);
 }
