@@ -4,4 +4,4 @@ var street = (_user$address = user.address) === null || _user$address === void 0
 street = (_user$address2 = user.address) === null || _user$address2 === void 0 ? void 0 : _user$address2.street;
 test((_a = a) === null || _a === void 0 ? void 0 : _a.b, 1);
 test((_a2 = a) === null || _a2 === void 0 ? void 0 : _a2.b, 1);
-1, (_a3 = a) === null || _a3 === void 0 ? void 0 : _a3.b, 2;
+1, (_a3 = a) !== null && _a3 !== void 0 && _a3.b, 2;
