@@ -1,7 +1,12 @@
+var _privateField = babelHelpers.classPrivateFieldLooseKey("privateField");
+
+var _privateFieldValue = babelHelpers.classPrivateFieldLooseKey("privateFieldValue");
+
 class Cl {
   constructor() {
     Object.defineProperty(this, _privateFieldValue, {
-      get: _get_privateFieldValue
+      get: _get_privateFieldValue,
+      set: void 0
     });
     Object.defineProperty(this, _privateField, {
       writable: true,
@@ -12,10 +17,6 @@ class Cl {
 
 }
 
-var _privateField = babelHelpers.classPrivateFieldLooseKey("privateField");
-
-var _privateFieldValue = babelHelpers.classPrivateFieldLooseKey("privateFieldValue");
-
 var _get_privateFieldValue = function () {
   return babelHelpers.classPrivateFieldLooseBase(this, _privateField)[_privateField];
 };
