@@ -1,7 +1,12 @@
+var _privateField = new WeakMap();
+
+var _privateFieldValue = new WeakMap();
+
 class Cl {
   constructor() {
     _privateFieldValue.set(this, {
-      get: _get_privateFieldValue
+      get: _get_privateFieldValue,
+      set: void 0
     });
 
     _privateField.set(this, {
@@ -14,10 +19,6 @@ class Cl {
 
 }
 
-var _privateField = new WeakMap();
-
-var _privateFieldValue = new WeakMap();
-
 var _get_privateFieldValue = function () {
   return babelHelpers.classPrivateFieldGet(this, _privateField);
 };
