@@ -1,5 +1,5 @@
 function* test() {
   (function (e) {
     throw e;
-  })(new Error((yield 'test')));
+  })(new Error(yield 'test'));
 }
