@@ -5,12 +5,16 @@ export default declare((api, options) => {
 
   // When enabled and plugins includes flow, all files should be parsed as if
   // the @flow pragma was provided.
-  const { all } = options;
+  const { all, enums } = options;
 
   if (typeof all !== "boolean" && typeof all !== "undefined") {
     throw new Error(".all must be a boolean, or undefined");
   }
 
+  if (typeof enums !== "boolean" && typeof enums !== "undefined") {
+    throw new Error(".enums must be a boolean, or undefined");
+  }
+
   return {
     name: "syntax-flow",
 
@@ -25,7 +29,7 @@ export default declare((api, options) => {
         return;
       }
 
-      parserOpts.plugins.push(["flow", { all }]);
+      parserOpts.plugins.push(["flow", { all, enums }]);
     },
   };
 });
