@@ -4,9 +4,7 @@ let TestClass = {
   testMethodFailure() {
     var _this = this;
 
-    return new Promise(
-    /*#__PURE__*/
-    function () {
+    return new Promise( /*#__PURE__*/function () {
       var _ref = babelHelpers.asyncToGenerator(function* (resolve) {
         console.log(_this);
         setTimeout(resolve, 1000);
