@@ -1,8 +1,6 @@
 var _coroutine = require("bluebird").coroutine;
 
-var foo =
-/*#__PURE__*/
-function () {
+var foo = /*#__PURE__*/function () {
   var _ref = _coroutine(function* () {
     var wat = yield bar();
   });
