@@ -6,6 +6,9 @@ import ReplaceSupers, {
 import optimiseCall from "@babel/helper-optimise-call-expression";
 import * as defineMap from "@babel/helper-define-map";
 import { traverse, template, types as t } from "@babel/core";
+import annotateAsPure from "@babel/helper-annotate-as-pure";
+
+import addCreateSuperHelper from "./inline-createSuper-helpers";
 
 type ReadonlySet<T> = Set<T> | { has(val: T): boolean };
 
@@ -34,6 +37,7 @@ export default function transformClass(
 
     classId: undefined,
     classRef: undefined,
+    superFnId: undefined,
     superName: undefined,
     superReturns: [],
     isDerived: false,
@@ -256,7 +260,7 @@ export default function transformClass(
   }
 
   function wrapSuperCall(bareSuper, superRef, thisRef, body) {
-    let bareSuperNode = bareSuper.node;
+    const bareSuperNode = bareSuper.node;
     let call;
 
     if (classState.isLoose) {
@@ -283,18 +287,11 @@ export default function transformClass(
 
       call = t.logicalExpression("||", bareSuperNode, t.thisExpression());
     } else {
-      bareSuperNode = optimiseCall(
-        t.callExpression(classState.file.addHelper("getPrototypeOf"), [
-          t.cloneNode(classState.classRef),
-        ]),
+      call = optimiseCall(
+        t.cloneNode(classState.superFnId),
         t.thisExpression(),
         bareSuperNode.arguments,
       );
-
-      call = t.callExpression(
-        classState.file.addHelper("possibleConstructorReturn"),
-        [t.thisExpression(), bareSuperNode],
-      );
     }
 
     if (
@@ -323,7 +320,7 @@ export default function transformClass(
 
     path.traverse(findThisesVisitor);
 
-    let thisRef = function() {
+    let thisRef = function () {
       const ref = path.scope.generateDeclaredUidIdentifier("this");
       thisRef = () => t.cloneNode(ref);
       return ref;
@@ -363,7 +360,7 @@ export default function transformClass(
       wrapSuperCall(bareSuper, classState.superName, thisRef, body);
 
       if (guaranteedSuperBeforeFinish) {
-        bareSuper.find(function(parentPath) {
+        bareSuper.find(function (parentPath) {
           // hit top so short circuit
           if (parentPath === path) {
             return true;
@@ -543,10 +540,26 @@ export default function transformClass(
   function pushInheritsToBody() {
     if (!classState.isDerived || classState.pushedInherits) return;
 
-    setState({ pushedInherits: true });
+    const superFnId = path.scope.generateUidIdentifier("super");
+
+    setState({ pushedInherits: true, superFnId });
 
     // Unshift to ensure that the constructor inheritance is set up before
     // any properties can be assigned to the prototype.
+
+    if (!classState.isLoose) {
+      classState.body.unshift(
+        t.variableDeclaration("var", [
+          t.variableDeclarator(
+            superFnId,
+            t.callExpression(addCreateSuperHelper(classState.file), [
+              t.cloneNode(classState.classRef),
+            ]),
+          ),
+        ]),
+      );
+    }
+
     classState.body.unshift(
       t.expressionStatement(
         t.callExpression(
@@ -565,11 +578,14 @@ export default function transformClass(
     const closureArgs = [];
 
     if (classState.isDerived) {
-      const arg = classState.extendsNative
-        ? t.callExpression(classState.file.addHelper("wrapNativeSuper"), [
-            t.cloneNode(superName),
-          ])
-        : t.cloneNode(superName);
+      let arg = t.cloneNode(superName);
+      if (classState.extendsNative) {
+        arg = t.callExpression(classState.file.addHelper("wrapNativeSuper"), [
+          arg,
+        ]);
+        annotateAsPure(arg);
+      }
+
       const param = classState.scope.generateUidIdentifierBasedOnNode(
         superName,
       );
