@@ -6,9 +6,7 @@ let Base = function Base() {};
 
 Base.prototype.test = 1;
 
-let Obj =
-/*#__PURE__*/
-function (_Base) {
+let Obj = /*#__PURE__*/function (_Base) {
   _inheritsLoose(Obj, _Base);
 
   function Obj() {
