@@ -1,6 +1,4 @@
-var Test =
-/*#__PURE__*/
-function () {
+var Test = /*#__PURE__*/function () {
   "use strict";
 
   function Test() {
