@@ -1,16 +1,16 @@
-var Foo =
-/*#__PURE__*/
-function (_Bar) {
+var Foo = /*#__PURE__*/function (_Bar) {
   "use strict";
 
   babelHelpers.inherits(Foo, _Bar);
 
+  var _super = babelHelpers.createSuper(Foo);
+
   function Foo() {
     var _this;
 
     babelHelpers.classCallCheck(this, Foo);
 
-    var fn = () => _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(Foo).call(this));
+    var fn = () => _this = _super.call(this);
 
     fn();
     return babelHelpers.possibleConstructorReturn(_this);
