@@ -2,9 +2,7 @@
 
 var _a2 = require("./a");
 
-var Foo =
-/*#__PURE__*/
-function () {
+var Foo = /*#__PURE__*/function () {
   function Foo() {
     babelHelpers.classCallCheck(this, Foo);
   }
