@@ -10,11 +10,11 @@ var Hello = function Hello() {
   };
 };
 
-var Outer =
-/*#__PURE__*/
-function (_Hello) {
+var Outer = /*#__PURE__*/function (_Hello) {
   babelHelpers.inherits(Outer, _Hello);
 
+  var _super = babelHelpers.createSuper(Outer);
+
   function Outer() {
     var _this2 = this;
 
@@ -22,15 +22,13 @@ function (_Hello) {
 
     babelHelpers.classCallCheck(this, Outer);
 
-    var Inner =
-    /*#__PURE__*/
-    function () {
+    var Inner = /*#__PURE__*/function () {
       function Inner() {
         babelHelpers.classCallCheck(this, Inner);
       }
 
       babelHelpers.createClass(Inner, [{
-        key: _this = babelHelpers.possibleConstructorReturn(_this2, babelHelpers.getPrototypeOf(Outer).call(_this2)),
+        key: _this = _super.call(_this2),
         value: function value() {
           return 'hello';
         }
