@@ -1,7 +1,5 @@
 // #1649
-var Foo =
-/*#__PURE__*/
-function () {
+var Foo = /*#__PURE__*/function () {
   "use strict";
 
   function Foo() {
