@@ -1,10 +1,10 @@
-var Foo =
-/*#__PURE__*/
-function (_Bar) {
+var Foo = /*#__PURE__*/function (_Bar) {
   "use strict";
 
   babelHelpers.inherits(Foo, _Bar);
 
+  var _super = babelHelpers.createSuper(Foo);
+
   function Foo() {
     var _this;
 
@@ -13,7 +13,7 @@ function (_Bar) {
     var fn = () => babelHelpers.assertThisInitialized(_this);
 
     fn();
-    return _this = babelHelpers.possibleConstructorReturn(this, babelHelpers.getPrototypeOf(Foo).call(this));
+    return _this = _super.call(this);
   }
 
   return Foo;
