@@ -4,7 +4,11 @@ import { types as t } from "@babel/core";
 export default declare((api, options) => {
   api.assertVersion(7);
 
-  const { loose = false, useBuiltIns = false } = options;
+  const {
+    loose = false,
+    useBuiltIns = false,
+    allowArrayLike = false,
+  } = options;
 
   if (typeof loose !== "boolean") {
     throw new Error(`.loose must be a boolean or undefined`);
@@ -85,6 +89,7 @@ export default declare((api, options) => {
       this.scope = opts.scope;
       this.kind = opts.kind;
       this.arrayOnlySpread = opts.arrayOnlySpread;
+      this.allowArrayLike = opts.allowArrayLike;
       this.addHelper = opts.addHelper;
     }
 
@@ -141,7 +146,7 @@ export default declare((api, options) => {
       ) {
         return node;
       } else {
-        return this.scope.toArray(node, count);
+        return this.scope.toArray(node, count, this.allowArrayLike);
       }
     }
 
@@ -166,7 +171,7 @@ export default declare((api, options) => {
         let patternId;
         let node;
 
-        if (this.kind === "const") {
+        if (this.kind === "const" || this.kind === "let") {
           patternId = this.scope.generateUidIdentifier(tempId.name);
           node = this.buildVariableDeclaration(patternId, tempConditional);
         } else {
@@ -203,6 +208,8 @@ export default declare((api, options) => {
         const key = prop.key;
         if (t.isIdentifier(key) && !prop.computed) {
           keys.push(t.stringLiteral(key.name));
+        } else if (t.isTemplateLiteral(prop.key)) {
+          keys.push(t.cloneNode(prop.key));
         } else if (t.isLiteral(key)) {
           keys.push(t.stringLiteral(String(key.value)));
         } else {
@@ -521,6 +528,7 @@ export default declare((api, options) => {
           scope: scope,
           nodes: nodes,
           arrayOnlySpread,
+          allowArrayLike,
           addHelper: name => this.addHelper(name),
         });
 
@@ -546,6 +554,7 @@ export default declare((api, options) => {
           scope: scope,
           nodes: nodes,
           arrayOnlySpread,
+          allowArrayLike,
           addHelper: name => this.addHelper(name),
         });
         destructuring.init(pattern, ref);
@@ -564,6 +573,7 @@ export default declare((api, options) => {
           scope: scope,
           nodes: nodes,
           arrayOnlySpread,
+          allowArrayLike,
           addHelper: name => this.addHelper(name),
         });
 
@@ -597,6 +607,7 @@ export default declare((api, options) => {
         }
 
         path.replaceWithMultiple(nodes);
+        path.scope.crawl();
       },
 
       VariableDeclaration(path) {
@@ -621,6 +632,7 @@ export default declare((api, options) => {
             scope: scope,
             kind: node.kind,
             arrayOnlySpread,
+            allowArrayLike,
             addHelper: name => this.addHelper(name),
           });
 
