@@ -5,3 +5,5 @@ foo4.default;
 foo4.default;
 foo4.foo3;
 (0, foo4.foo3)();
+(0, foo4.foo3)``;
+(0, foo4.foo3)?.();
