@@ -10,7 +10,7 @@
     factory();
     global.looseModuleNameInput = mod.exports;
   }
-})(this, function () {
+})(typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : this, function () {
   "use strict";
 
   foobar();
