@@ -1,6 +1,4 @@
-var Ref =
-/*#__PURE__*/
-function () {
+var Ref = /*#__PURE__*/function () {
   "use strict";
 
   function Ref() {
@@ -12,9 +10,7 @@ function () {
   return Ref;
 }();
 
-var X =
-/*#__PURE__*/
-function () {
+var X = /*#__PURE__*/function () {
   "use strict";
 
   function X() {
