@@ -1,6 +1,4 @@
-var concat =
-/*#__PURE__*/
-function () {
+var concat = /*#__PURE__*/function () {
   var _ref = babelHelpers.asyncToGenerator(function* () {
     var x = arguments.length <= 0 ? undefined : arguments[0];
     var y = arguments.length <= 1 ? undefined : arguments[1];
@@ -11,9 +9,7 @@ function () {
   };
 }();
 
-var x =
-/*#__PURE__*/
-function () {
+var x = /*#__PURE__*/function () {
   var _ref2 = babelHelpers.asyncToGenerator(function* () {
     if (noNeedToWork) return 0;
 
