@@ -8,9 +8,7 @@ function _defineProperties(target, props) { for (var i = 0; i < props.length; i+
 
 function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }
 
-var Thing =
-/*#__PURE__*/
-function () {
+var Thing = /*#__PURE__*/function () {
   function Thing() {
     _classCallCheck(this, Thing);
   }
