@@ -1,19 +1,13 @@
-var _ref =
-/*#__PURE__*/
-<div>child</div>;
+var _ref = <div>child</div>;
 
-var _ref3 =
-/*#__PURE__*/
-<p>Parent</p>;
+var _ref3 = <p>Parent</p>;
 
 (function () {
   const AppItem = () => {
     return _ref;
   };
 
-  var _ref2 =
-  /*#__PURE__*/
-  <div>
+  var _ref2 = <div>
           {_ref3}
           <AppItem />
         </div>;
