@@ -1,10 +1,6 @@
-var _ref =
-/*#__PURE__*/
-<b></b>;
+var _ref = <b></b>;
 
-var _ref2 =
-/*#__PURE__*/
-<span></span>;
+var _ref2 = <span></span>;
 
 function render() {
   var children = _ref;
