@@ -1,9 +1,7 @@
 function render() {
   var title = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
 
-  var _ref =
-  /*#__PURE__*/
-  <Component title={title} />;
+  var _ref = <Component title={title} />;
 
   return () => _ref;
 }
