@@ -1,7 +1,5 @@
 function render(text) {
-  var _ref =
-  /*#__PURE__*/
-  <foo>{text}</foo>;
+  var _ref = <foo>{text}</foo>;
 
   return function () {
     return _ref;
@@ -11,9 +9,7 @@ function render(text) {
 var Foo2 = require("Foo");
 
 function createComponent(text) {
-  var _ref2 =
-  /*#__PURE__*/
-  <Foo2>{text}</Foo2>;
+  var _ref2 = <Foo2>{text}</Foo2>;
 
   return function render() {
     return _ref2;
