@@ -1,9 +1,7 @@
 function render() {
   var text = getText();
 
-  var _ref =
-  /*#__PURE__*/
-  <foo>{text}</foo>;
+  var _ref = <foo>{text}</foo>;
 
   return function () {
     return _ref;
