@@ -1,9 +1,7 @@
 function render(_ref) {
   let text = _ref.text;
 
-  var _ref2 =
-  /*#__PURE__*/
-  <Component text={text} />;
+  var _ref2 = <Component text={text} />;
 
   return () => _ref2;
 }
