@@ -1,7 +1,5 @@
 function render(offset) {
-  var _ref =
-  /*#__PURE__*/
-  <div tabIndex={offset + 1} />;
+  var _ref = <div tabIndex={offset + 1} />;
 
   return function () {
     return _ref;
