@@ -1,4 +1,4 @@
-var es3 = React.createElement(F, {
+var es3 = /*#__PURE__*/React.createElement(F, {
   aaa: true,
   "new": true,
   "const": true,
