@@ -1,4 +1,4 @@
-var x = React.createElement("div", {
+var x = /*#__PURE__*/React.createElement("div", {
   attr1: "foo" + "bar",
   attr2: "foo" + "bar" + "baz" + "bug",
   attr3: "foo" + "bar" + "baz" + "bug",
