@@ -1,8 +1,6 @@
 var _regeneratorRuntime = require("@babel/runtime-corejs2/regenerator");
 
-void
-/*#__PURE__*/
-_regeneratorRuntime.mark(function _callee() {
+void /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
   return _regeneratorRuntime.wrap(function _callee$(_context) {
     while (1) switch (_context.prev = _context.next) {
       case 0:
