@@ -1,6 +1,7 @@
 // @flow
 
 export const TopLevelOptions = {
+  bugfixes: "bugfixes",
   configPath: "configPath",
   corejs: "corejs",
   debug: "debug",
@@ -14,6 +15,7 @@ export const TopLevelOptions = {
   spec: "spec",
   targets: "targets",
   useBuiltIns: "useBuiltIns",
+  browserslistEnv: "browserslistEnv",
 };
 
 export const ModulesOption = {
@@ -31,22 +33,3 @@ export const UseBuiltInsOption = {
   entry: "entry",
   usage: "usage",
 };
-
-export const TargetNames = {
-  esmodules: "esmodules",
-  node: "node",
-  browsers: "browsers",
-  chrome: "chrome",
-  opera: "opera",
-  edge: "edge",
-  firefox: "firefox",
-  safari: "safari",
-  ie: "ie",
-  ios: "ios",
-  android: "android",
-  electron: "electron",
-  samsung: "samsung",
-
-  // deprecated
-  uglify: "uglify",
-};
