@@ -10,7 +10,6 @@ export default (_: any, opts: Object = {}) => {
     decoratorsBeforeExport,
     pipelineProposal = "minimal",
     recordAndTupleSyntax: recordAndTupleSyntax = "hash",
-    moduleAttributesVersion = "may-2020",
   } = opts;
 
   return {
@@ -22,14 +21,9 @@ export default (_: any, opts: Object = {}) => {
     ],
     plugins: [
       babelPlugins.syntaxDecimal,
-      [
-        babelPlugins.syntaxModuleAttributes,
-        { version: moduleAttributesVersion },
-      ],
       [babelPlugins.syntaxRecordAndTuple, { syntaxType: recordAndTupleSyntax }],
       babelPlugins.proposalExportDefaultFrom,
       [babelPlugins.proposalPipelineOperator, { proposal: pipelineProposal }],
-      babelPlugins.proposalPrivatePropertyInObject,
       babelPlugins.proposalDoExpressions,
     ],
   };
