@@ -1,7 +1,9 @@
 import * as t from "../lib";
 
 describe("regressions", () => {
-  it("jest .toMatchInlineSnapshot used 'Line' for comments", () => {
+  const babel7 = process.env.BABEL_TYPES_8_BREAKING ? it.skip : it;
+
+  babel7("jest .toMatchInlineSnapshot used 'Line' for comments", () => {
     expect(() => {
       t.file(t.program([]), [{ type: "Line" }]);
     }).not.toThrow();
