@@ -5,23 +5,23 @@ const packageJSONPath = path.resolve(cwd, "./package.json");
 const content = JSON.parse(fs.readFileSync(packageJSONPath));
 
 let bumped = false;
-function bumpBabelDependency(dependencies) {
+function bumpBabelDependency(dependencies, version) {
   for (const dep of Object.keys(dependencies)) {
     if (dep.startsWith("@babel/") && !dependencies[dep].includes(":")) {
-      dependencies[dep] = "latest";
+      dependencies[dep] = version;
       bumped = true;
     }
   }
 }
 
 if ("peerDependencies" in content) {
-  bumpBabelDependency(content.peerDependencies);
+  bumpBabelDependency(content.peerDependencies, "*");
 }
 if ("devDependencies" in content) {
-  bumpBabelDependency(content.devDependencies);
+  bumpBabelDependency(content.devDependencies, "latest");
 }
 if ("dependencies" in content) {
-  bumpBabelDependency(content.dependencies);
+  bumpBabelDependency(content.dependencies, "latest");
 }
 
 if (bumped) {
