@@ -1,10 +1,11 @@
 #!/bin/bash
 set -e
 
+node="yarn node"
 jestArgs="--coverage"
 
 if [ -n "$CI" ]; then
   jestArgs="${jestArgs} --maxWorkers=4 --ci"
 fi
 
-node_modules/.bin/jest $jestArgs
+$node "$(yarn bin jest)" $jestArgs
