@@ -1,11 +1,11 @@
 #!/bin/bash
 set -e
 
-node="node"
+node="yarn node"
 jestArgs=()
 
 if [ "$TEST_DEBUG" ]; then
-  node="node --inspect-brk"
+  node="$node --inspect-brk"
   jestArgs+=("--runInBand")
 fi
 
@@ -20,7 +20,7 @@ if [ -n "$TEST_GREP" ]; then
 fi
 
 if [ -n "$TEST_ONLY" ]; then
-  jestArgs+=("(packages|codemods)/.*$TEST_ONLY.*/test")
+  jestArgs+=("(packages|codemods|eslint)/.*$TEST_ONLY.*/test")
 fi
 
-$node node_modules/jest/bin/jest.js "${jestArgs[@]}"
+$node "$(yarn bin jest)" "${jestArgs[@]}"
